local mod = ...



-- *************************************************************************************************************
-- Stump Component -------------------------------------------------------------------------------------
-- Removes the stump after some time
-- *************************************************************************************************************

local COMP_STUMP = {
	TypeName = "COMP_STUMP",
	ParentType = "COMPONENT",
	Properties = {
		{ Name = "DaysLeft", Type = "integer", Default = 28, Flags = { "SAVE_GAME" } },
    }
}


-- Init
function COMP_STUMP:init()

    -- Randomise the lifecycle a bit
    if self.DaysLeft == 28 then
        self.DaysLeft = math.random(24, 30)
    end

    -- Daily script
    local compMainGameLoop = self:getLevel():find("COMP_MAIN_GAME_LOOP")
    event.register(self, compMainGameLoop.ON_NEW_DAY, function()

        -- Count down to zero and then delete the stump
        self.DaysLeft = self.DaysLeft - 1
        if self.DaysLeft < 0 then
            self:getOwner():destroy()
        end

    end)

end


-- Register custom Class
mod:registerClass(COMP_STUMP)



-- Building Asset Processor -------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/Stump1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Stump Prefabs -------------------------------------------------------------------------------------
local listStumpPrefab = {}

local function registerStump(mesh)

    -- create prefab
    mod:registerAssetId("models/Stump1.fbx/Prefab/" .. mesh, "PREFAB_STUMP_" .. mesh)

    -- ground
    mod:registerPrefabComponent("PREFAB_STUMP_" .. mesh, {
        DataType = "COMP_GROUNDED",
        AutoDisable = true,
    })

    -- stump component
    mod:registerPrefabComponent("PREFAB_STUMP_" .. mesh, { DataType = "COMP_STUMP" } )

    -- record in prefab list for use later
    table.insert(listStumpPrefab, "PREFAB_STUMP_" .. mesh)

end

registerStump("STUMP1")
registerStump("STUMP2")
registerStump("STUMP3")



-- Jobs -------------------------------------------------------------------------------------
mod:overrideAsset({
    Id = "WOOD_CUTTER",
	DefaultBehavior = "BEHAVIOR_WOODCUTTER_STUMP",
})



-- Functions -------------------------------------------------------------------------------------
mod:overrideAsset({
    Id = "BUILDING_FUNCTION_WOODCUTTER",
    RelatedJob = {
        Job = "WOOD_CUTTER",
        Behavior = "BEHAVIOR_WOODCUTTER_STUMP",
    },
})
